@@ -10,11 +10,11 @@ matlab <- function() {
   "
   accumarray, acot, acoth, acsc, acsch, and, angle, ans, asec, asech,
   beep, blank, blkdiag, bsxfun,
-  cart2pol, cart2sph, ceil, clear, compan, cond, conv, cot, coth, cross,
-      csc, csch,
+  cart2pol, cart2sph, ceil, circshift, clear, compan, cond, conv, cot, coth,
+      cross, csc, csch,
   deblank, deconv, deg2rad, detrend, deval, disp, dot,
   eig, eigint, ellipj, ellipke, erf, erfc, erfcinv, erfcx, erfi, erfinv,
-      errorbar, expm, eye, ezcontour, ezmesh, ezplot, ezpolar,
+      errorbar, expint, expm, eye, ezcontour, ezmesh, ezplot, ezpolar,
   fact, factors, figure, findstr, flipdim, fliplr, flipud, fminbnd,
       fminsearch, fplot, fsolve, fzero,
   gammainc, gcd, gradient,
@@ -27,17 +27,17 @@ matlab <- function() {
   ode23, ones, or, orth,
   pascal, pchip, peaks, perms, piecewise, pinv, plotyy, pol2cart, polar,
       polyfit, polyint, polylog, polyval, pow2, ppval, primes,
-  quad, quad2d, quadgk, quadl, quiver,
+  quad, quad2d, quadgk, quadl, quadv, quiver,
   rad2deg, randi, randn, randsample, rat, rats, regexp, regexpi, regexpreg,
       rem, repmat, roots, rosser, rot90, rref, runge,
-  sec, sech, sinc, size, sph2cart, sqrtm, std, str2num, strcat, strcmp,
-      strcmpi, strfind, strfindi, strjust, strrep, subspace,
+  sec, sech, sinc, size, sortrows, sph2cart, sqrtm, std, str2num, strcat,
+      strcmp, strcmpi, strfind, strfindi, strjust, strrep, subspace,
   tic, toc, trapz, tril, triu,
   vander, vectorfield,
-  whittaker, who, wilkinson,
+  what, who, wilkinson,
   zeros, zeta.",
   "", 
-  "The following Matlab function names have been capitalized in `pracma' to",
+  "The following Matlab function names have been capitalized in 'pracma' to",
   "avoid shadowing functions from R base or one of its recommended packages:",
   "
   Diag, factors, finds, Fix, Imag, Lcm, Mode, Norm, nullspace (null),
@@ -46,7 +46,10 @@ matlab <- function() {
   "To use 'ans' instead of 'ans()' (i.e., as is common practice in Matlab)",
   "type (and similar for other Matlab commands):",
   "
-  makeActiveBinding('ans', function() .Last.value, .GlobalEnv)",
+  makeActiveBinding('ans', function() .Last.value, .GlobalEnv)
+  makeActiveBinding('who', who, .GlobalEnv)",
+  "",
+  "etc. after loading the 'pracma' package.",
   "\n",
     sep = "\n", collapse = ""))
   
